<?php

namespace App\Http\Controllers\Admin\Base;

use App\Http\Controllers\Controller;
use App\Repositories\Criteria\TCM\PatientCriteria;
use App\Repositories\Enums\ResponseCodeEnum;
use App\Repositories\Models\Base\Role;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use Prettus\Validator\Contracts\ValidatorInterface;
use Prettus\Validator\Exceptions\ValidatorException;
use App\Contracts\Repositories\Base\RoleRepository;
use App\Repositories\Validators\Base\RoleValidator;

/**
 * Class RolesController.
 *
 * @package namespace App\Http\Controllers\Admin\Base;
 */
class RoleController extends Controller
{
    /**
     * @var RoleRepository
     */
    protected $repository;

    /**
     * @var RoleValidator
     */
    protected $validator;

    /**
     * RolesController constructor.
     *
     * @param RoleRepository $repository
     * @param RoleValidator $validator
     */
    public function __construct(RoleRepository $repository, RoleValidator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
    }

    public function index()
    {
        $lists = $this->repository->paginate(request('per_page', self::PAGE_NUM));
        return Response::success($lists);
    }


    public function store(Request $request)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_CREATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE)));
            $data['guard_name'] = 'api';
            $role = $this->repository->create($data);

            return Response::success($role);
        } catch (\Exception $e) {
            return $this->errorStore($e);
        }
    }

    public function show($id)
    {
        $patient = $this->repository->find($id);
        return Response::success($patient);
    }

    public function update(Request $request, $id)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_UPDATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_UPDATE)));
            $data['guard_name'] = 'api';
            $role = $this->repository->update($data, $id);
            return Response::success($role);
        } catch (\Exception $e) {
            $this->errorStore($e);
        }
    }

    public function destroy($id)
    {
        try {
            $re = $this->repository->delete($id);
            if ($re) {
                return Response::success(null, T('successfully delete.'));
            }
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }

    public function lists(Request $request)
    {
        $lists = $this->repository->skipPresenter()->orderBy('sort', 'desc')->get(['name', 'id']);
        return Response::success($lists);
    }
}
