<?php

namespace App\Http\Controllers\Admin\CMS;

use App\Http\Controllers\Controller;
use App\Repositories\Enums\ResponseCodeEnum;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use Prettus\Validator\Contracts\ValidatorInterface;
use App\Contracts\Repositories\CMS\BannerRepository;
use App\Repositories\Validators\CMS\BannerValidator;

/**
 * Class BannersController.
 *
 * @package namespace App\Http\Controllers\CMS;
 */
class BannersController extends Controller
{
    /**
     * @var BannerRepository
     */
    protected $repository;

    /**
     * @var BannerValidator
     */
    protected $validator;

    /**
     * BannersController constructor.
     *
     * @param BannerRepository $repository
     * @param BannerValidator $validator
     */
    public function __construct(BannerRepository $repository, BannerValidator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
    }

    public function index(Request $request)
    {
        $lists = $this->repository->paginate(request('per_page', self::PAGE_NUM));

        return Response::success($lists);
    }


    public function store(Request $request)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_CREATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE)));
            $model = $this->repository->create($data);
            return Response::success($model);
        } catch (\Exception $e) {
            return $this->errorStore($e);
        }
    }

    public function show($id)
    {
        $model = $this->repository->find($id);
        return Response::success($model);
    }


    public function update(Request $request, $id)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_UPDATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_UPDATE)));
            $model = $this->repository->update($data, $id);
            return Response::success($model);
        } catch (\Exception $e) {
            $this->errorStore($e);
        }
    }

    public function destroy($id)
    {
        try {
            $this->repository->delete($id);
            return Response::success(null, T('successfully delete.'));
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }

    public function delete(Request $request)
    {
        try {
            $this->validate($request, [
                'ids' => 'required|array',
            ]);

            $ids = $request->get('ids');
            $this->repository->whereIn('id', $ids)->delete();
            return Response::success(null, T('successfully delete.'));
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }
}
