<?php

namespace App\Http\Controllers\Admin\TCM;

use App\Http\Controllers\Controller;
use App\Repositories\Criteria\TCM\PatientCriteria;
use App\Repositories\Enums\ResponseCodeEnum;
use App\Repositories\Models\TCM\MedicalRecord;
use Illuminate\Http\Request;

use App\Http\Requests;
use Jiannei\Response\Laravel\Support\Facades\Response;
use Overtrue\LaravelPinyin\Facades\Pinyin;
use Prettus\Validator\Contracts\ValidatorInterface;
use Prettus\Validator\Exceptions\ValidatorException;
use App\Contracts\Repositories\TCM\MedicalRecordRepository;
use App\Repositories\Validators\TCM\MedicalRecordValidator;

/**
 * Class MedicalRecordsController.
 *
 * @package namespace App\Http\Controllers\TCM;
 */
class MedicalRecordController extends Controller
{
    /**
     * @var MedicalRecordRepository
     */
    protected $repository;

    /**
     * @var MedicalRecordValidator
     */
    protected $validator;

    /**
     * MedicalRecordsController constructor.
     *
     * @param MedicalRecordRepository $repository
     * @param MedicalRecordValidator $validator
     */
    public function __construct(MedicalRecordRepository $repository, MedicalRecordValidator $validator)
    {
        $this->repository = $repository;
        $this->validator = $validator;
    }

    public function index()
    {
        $lists = $this->repository->paginate(request('per_page', self::PAGE_NUM));
        return Response::success($lists);
    }


    public function store(Request $request)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_CREATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_CREATE)));
            $data['admin_id'] = login_admin_id();
            $record = $this->repository->create($data);
            return Response::success($record);
        } catch (\Exception $e) {
            return $this->errorStore($e);
        }
    }

    public function show($id)
    {
        $patient = $this->repository->find($id);
        return Response::success($patient);
    }

    public function update(Request $request, $id)
    {
        $this->validate($request, $this->validator->getRules(ValidatorInterface::RULE_UPDATE));
        try {
            $data = $request->only(array_keys($this->validator->getRules(ValidatorInterface::RULE_UPDATE)));
            $record = $this->repository->update($data, $id);
            return Response::success($record);
        } catch (\Exception $e) {
            $this->errorStore($e);
        }
    }

    public function destroy($id)
    {
        try {
            $re = $this->repository->delete($id);
            if ($re) {
                return Response::success(null, T('successfully delete.'));
            }
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        } catch (\Exception $exception) {
            return Response::fail(T('Delete failed.'), ResponseCodeEnum::SERVICE_UPDATE_DATA_ERROR);
        }
    }
}
