<?php

namespace App\Repositories\Criteria\Inform;

use App\Repositories\Models\Inform\Category;
use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class InformationCriteria.
 *
 * @package namespace App\Repositories\Criteria\Inform;
 */
class InformationCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($title = $this->request->get('title')) {
            $model = $model->where('title', 'like', "%{$title}%");
        }

        if (($status = $this->request->get('status', false)) !== false) {
            $model = $model->where('status', '=', $status);
        }

        if ($category_id = $this->request->get('category_id')) {

            $ids = Category::sonGroup($category_id);
            $ids[] = $category_id;

            $model = $model->whereIn('category_id', $ids);
        }

        if ($tag = $this->request->get('tag')) {
            switch ($tag) {
                case 'new':
                    $model = $model->orderByDesc('id');
                    break;
                case 'hot':
                    $model = $model->orderByDesc('view_count')->orderByDesc('id');
                    break;
                case 'good':
                    $model = $model->orderByDesc('good_count')->orderByDesc('id');
                    break;
            }
        } else {
            $model = $model->orderByDesc('sort')->orderByDesc('id');
        }

        $user = login_admin();
        $user_id = $user->id;
        if ($user_id > 1) {
            $model = $model->whereIn('category_id', Category::byRoleGetIds($user->role_id));
        }

        $model = $model->orderByDesc('sort')->orderByDesc('id');
        return $model;
    }
}
