<?php

namespace App\Repositories\Criteria\TCM;

use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class PrescriptionCriteria.
 *
 * @package namespace App\Repositories\Criteria\TCM;
 */
class PrescriptionCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($name = $this->request->get('name')) {
            $model = $model->whereHas('patient', function ($query) use ($name) {
                return $query->where('name', 'like', "%{$name}%");
            });
        }


        if ($patient_id = $this->request->get('patient_id')) {
            $model = $model->where('patient_id', $patient_id);
        }


        if ($medical_record_id = $this->request->get('medical_record_id')) {
            $model = $model->where('medical_record_id', $medical_record_id);
        }

        if (($status = $this->request->get('status', false)) !== false) {
            $model = $model->where('status', '=', $status);
        }

        $model = $model->orderByDesc('id');

        return $model;
    }
}
